# azuma

[![PyPI version](https://badge.fury.io/py/azuma.svg)](https://badge.fury.io/py/azuma)
[![Test](https://github.com/ninoseki/azuma/actions/workflows/test.yml/badge.svg)](https://github.com/ninoseki/azuma/actions/workflows/test.yml)

Yet another [Sigma](https://github.com/SigmaHQ/sigma) library for Python.

[SigmaHQ/pySigma](https://github.com/SigmaHQ/pySigma) is for converting a Sigma rule into queries. But this library is for evaluating an input with a Sigma rule set in Python.

See [documentation](https://ninoseki.github.io/azuma/) for more details.

## Acknowledgement

This library is a fork of [CybercentreCanada/pysigma](https://github.com/CybercentreCanada/pysigma). Most of the things in this library are the result of their hard work.

## Alternatives

- https://github.com/binalyze/tigma
- https://github.com/bradleyjkemp/sigma-go
- https://github.com/confluentinc/confluent-sigma
- https://github.com/markuskont/go-sigma-rule-engine
- https://github.com/runreveal/sigmalite
